NMInboxStatusCountFilter class

Copyright (c) 2026 Netmera Research.

Constructors

NMInboxStatusCountFilter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCategoryList() → List<int>?
getIncludeExpired() → bool?
getStatus() → int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCategoryList(List<int> value) → dynamic
setIncludeExpired(bool value) → dynamic
setStatus(int value) → dynamic
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited