Netmera class

Copyright (c) 2025 Inomera Research. Author Initial Code

Constructors

Netmera()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

areNotificationsEnabled() → Future<bool?>
checkNotificationPermission() → Future<NotificationPermissionStatus?>
countForStatus(int status) → Future<int?>
disablePopupPresentation() → dynamic
disablePush() → dynamic
enablePopupPresentation() → dynamic
enablePush() → dynamic
fetchCategory(NetmeraCategoryFilter categoryFilter) → Future<List<NetmeraCategory>>
fetchCoupons(int page, int max) → Future<List<NetmeraCouponDetail>>
fetchInbox(NetmeraInboxFilter inboxFilter) → Future<List<NetmeraPushInbox>>
fetchNextCategory() → Future<List<NetmeraCategory>>
fetchNextPage() → Future<List<NetmeraPushInbox>>
getCurrentExternalId() → Future<String?>
getInboxCountForStatus(NMInboxStatusCountFilter filter) → Future<Map>
getUserCategoryPreferenceList() → Future<List<NetmeraCategoryPreference>>
handleInteractiveAction(NetmeraInteractiveAction netmeraInteractiveAction) → dynamic
handleLastMessage(NetmeraCategory category) → dynamic
handlePushObject(String pushId) → dynamic
inboxUpdateStatus(List<String> inboxList, int status) → Future
isNetmeraRemoteMessage(Map data) → bool
isPushEnabled() → Future<bool?>
kill() → dynamic
onNetmeraFirebasePushMessageReceived(String? from, Map data) → dynamic
onNetmeraHuaweiPushMessageReceived(String? from, Map data) → dynamic
onNetmeraNewToken(String pushToken) → dynamic
onWidgetUrlTriggered(Function handler) → dynamic
requestPermissionsForLocation() → dynamic
requestPushNotificationAuthorization() → dynamic
sendEvent(NetmeraEvent event) → void
setApiKey(String apiKey) → dynamic
setAppGroupName(String appGroupName) → dynamic
setBaseUrl(String baseUrl) → dynamic
setNetmeraMaxActiveRegions(int maxActiveRegions) → dynamic
setUserCategoryPreference(int categoryId, bool categoryEnabled) → Future
skipAppConfigAndSetBaseUrl(String baseUrl) → dynamic
startDataTransfer() → dynamic
stopDataTransfer() → dynamic
turnOffSendingEventAndUserUpdate(bool turnOff) → dynamic
updateAll(int inboxStatus) → Future
updateStatusByCategories(int inboxStatus, List<String> categoryList) → Future
updateUser(NetmeraUser user) → dynamic
updateUserAsync(NetmeraUser user) → dynamic