NetmeraCategoryPreference class

Copyright (c) 2026 Netmera Research.

Constructors

NetmeraCategoryPreference(int categoryId, String categoryName, bool optInStatus)
NetmeraCategoryPreference.fromJson(Map json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCategoryId() int?
getCategoryName() String?
getOptInStatus() bool?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited