NetmeraInboxFilter class

Copyright (c) 2026 Netmera Research.

Constructors

NetmeraInboxFilter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCategories() → List<String>?
getIncludeExpiredObjects() → bool?
getPageSize() → int?
getStatus() → int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCategories(List<String>? value) → dynamic
setIncludeExpiredObjects(bool value) → dynamic
setPageSize(int value) → dynamic
setStatus(int value) → dynamic
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited