NetmeraInteractiveAction class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAction() → Map?
getActionIconName() → String?
getActionTitle() → String?
getCustomJson() → Map?
getId() → String?
getPushAction() → NetmeraPushAction?
Returns the push action as a typed NetmeraPushAction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAction(Map action) → dynamic
setActionIconName(String actionIconName) → dynamic
setActionTitle(String actionTitle) → dynamic
setCustomJson(Map customJson) → dynamic
setId(String id) → dynamic
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited