NetmeraPushInbox class

Copyright (c) 2026 Netmera Research.

Constructors

NetmeraPushInbox()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBody() → String?
getCarousel() → List?
getCategories() → List?
getCategory() → String?
getCustomJson() → Map?
getExternalId() → String?
getInboxStatus() → int?
getInteractiveActions() → List<NetmeraInteractiveAction>?
getMediaAttachmentUrl() → String?
getPopUpExpirationTime() → String?
getPushAction() → Map?
getPushId() → String?
getPushInstanceId() → String?
getPushType() → int?
getSendDate() → String?
getSubtitle() → String?
getTitle() → String?
getWebPage() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBody(String value) → dynamic
setCarousel(List value) → dynamic
setCategories(List value) → dynamic
setCategory(String value) → dynamic
setCustomJson(Map value) → dynamic
setExternalId(String value) → dynamic
setInboxStatus(int value) → dynamic
setInteractiveActions(List<NetmeraInteractiveAction> value) → dynamic
setPopUpExpirationTime(String value) → dynamic
setPushAction(Map value) → dynamic
setPushId(String value) → dynamic
setPushInstanceId(String value) → dynamic
setPushType(int value) → dynamic
setSendDate(String value) → dynamic
setSubtitle(String value) → dynamic
setTitle(String value) → dynamic
setTMediaAttachmentUrl(String value) → dynamic
setWebPage(String value) → dynamic
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map json) → dynamic