NetmeraPushLifecycleCallbacks class

Flutter-idiomatic push lifecycle API. Use this instead of the deprecated NetmeraPushBroadcastReceiver.

Only one of NetmeraPushLifecycleCallbacks or NetmeraPushBroadcastReceiver should be active at a time — they share the same MethodChannel.

Constructors

NetmeraPushLifecycleCallbacks()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initialize({PushRegisterHandler? onPushRegister, PushObjectHandler? onPushReceive, PushObjectHandler? onPushOpen, PushObjectHandler? onPushDismiss, PushButtonClickedHandler? onPushButtonClicked, PushCarouselHandler? onCarouselObjectSelected}) Future<void>
Registers push lifecycle callbacks and initialises the Flutter Method Channel.
setBackgroundMessageHandler(BackgroundPushHandler handler) Future<void>
Registers a background push handler. Must be called before runApp with a top-level function. Android only — no-op on iOS.