NetmeraEventBatteryLevel class

Copyright (c) 2026 Netmera Research.

Inheritance

Constructors

NetmeraEventBatteryLevel()

Properties

hashCode → int
The hash code for this object.
no setterinherited
revenue ↔ double?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBatteryLevel() → int?
getCode() → String
override
getRevenue() → double?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBatteryLevel(int value) → dynamic
setRevenue(double value) → dynamic
inherited
toJson() → Map<String, Object?>
Copyright (c) 2026 Netmera Research.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited