NetmeraEventPurchase class

Copyright (c) 2026 Netmera Research.

Inheritance

Constructors

NetmeraEventPurchase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
revenue ↔ double?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCode() → String
override
getCoupon() → String?
getDiscount() → double?
getGrandTotal() → double?
getItemCount() → int?
getLineItems() → List<NetmeraLineItem>?
getPaymentMethod() → String?
getProductCount() → int?
getRevenue() → double?
inherited
getShippingCost() → double?
getSubTotal() → double?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCoupon(String value) → dynamic
setDiscount(double value) → dynamic
setGrandTotal(double value) → dynamic
setItemCount(int value) → dynamic
setLineItems(List<NetmeraLineItem> value) → dynamic
setPaymentMethod(String value) → dynamic
setProductCount(int value) → dynamic
setRevenue(double value) → dynamic
inherited
setShippingCost(double value) → dynamic
setSubTotal(double value) → dynamic
toJson() → Map<String, Object?>
Copyright (c) 2026 Netmera Research.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited