NetmeraLineItem class

Copyright (c) 2026 Netmera Research.

Inheritance

Constructors

NetmeraLineItem()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBrandId() → String?
inherited
getBrandName() → String?
inherited
getCampaignId() → String?
inherited
getCategoryIds() → List<String>?
inherited
getCategoryNames() → List<String>?
inherited
getCount() → int?
getId() → String?
inherited
getKeywords() → List<String>?
inherited
getName() → String?
inherited
getPrice() → double?
inherited
getVariant() → String?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBrandId(String value) → dynamic
inherited
setBrandName(String value) → dynamic
inherited
setCampaignId(String value) → dynamic
inherited
setCategoryIds(List<String> value) → dynamic
inherited
setCategoryNames(List<String> value) → dynamic
inherited
setCount(int value) → dynamic
setId(String value) → dynamic
inherited
setKeywords(List<String> value) → dynamic
inherited
setName(String value) → dynamic
inherited
setPrice(double value) → dynamic
inherited
setVariant(String value) → dynamic
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited