NetmeraEventContent class abstract

Copyright (c) 2026 Netmera Research.

Inheritance
Implementers

Constructors

NetmeraEventContent()

Properties

hashCode → int
The hash code for this object.
no setterinherited
revenue ↔ double?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCategoryIds() → List<String>?
getCategoryNames() → List<String>?
getCode() → String
inherited
getId() → String?
getKeywords() → List<String>?
getName() → String?
getProvider() → String?
getRevenue() → double?
inherited
getType() → int?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCategoryIds(List<String> value) → dynamic
setCategoryNames(List<String> value) → dynamic
setId(String value) → dynamic
setKeywords(List<String> value) → dynamic
setName(String value) → dynamic
setProvider(String value) → dynamic
setRevenue(double value) → dynamic
inherited
setType(int value) → dynamic
toJson() → Map<String, Object?>
Copyright (c) 2026 Netmera Research.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

TYPE_AUDIO → const int
TYPE_IMAGE → const int
TYPE_OTHER → const int
TYPE_TEXT → const int
TYPE_VIDEO → const int