NetmeraEventContentView class

Copyright (c) 2026 Netmera Research.

Inheritance

Constructors

NetmeraEventContentView()

Properties

hashCode → int
The hash code for this object.
no setterinherited
revenue ↔ double?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCategoryIds() → List<String>?
inherited
getCategoryNames() → List<String>?
inherited
getCode() → String
override
getId() → String?
inherited
getKeywords() → List<String>?
inherited
getName() → String?
inherited
getProvider() → String?
inherited
getRevenue() → double?
inherited
getType() → int?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCategoryIds(List<String> value) → dynamic
inherited
setCategoryNames(List<String> value) → dynamic
inherited
setId(String value) → dynamic
inherited
setKeywords(List<String> value) → dynamic
inherited
setName(String value) → dynamic
inherited
setProvider(String value) → dynamic
inherited
setRevenue(double value) → dynamic
inherited
setType(int value) → dynamic
inherited
toJson() → Map<String, Object?>
Copyright (c) 2026 Netmera Research.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited