Netmera class

Copyright (c) 2026 Netmera Research.

Constructors

Netmera()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

areNotificationsEnabled() Future<bool?>
checkNotificationPermission() Future<NotificationPermissionStatus?>
countForStatus(int status) Future<int?>
disablePopupPresentation() → dynamic
disablePush() → dynamic
dismissAllPresentations() → dynamic
enablePopupPresentation() → dynamic
enablePush() → dynamic
fetchCategory(NetmeraCategoryFilter categoryFilter) Future<List<NetmeraCategory>>
fetchCoupons(int page, int max) Future<List<NetmeraCouponDetail>>
fetchInbox(NetmeraInboxFilter inboxFilter) Future<List<NetmeraPushInbox>>
fetchNextCategory() Future<List<NetmeraCategory>>
fetchNextPage() Future<List<NetmeraPushInbox>>
getCurrentExternalId() Future<String?>
getEmailPermission() Future<bool>
getInboxCountForStatus(NMInboxStatusCountFilter filter) Future<Map>
getSmsPermission() Future<bool>
getUserCategoryPreferenceList() Future<List<NetmeraCategoryPreference>>
getWhatsAppPermission() Future<bool>
handleInteractiveAction(NetmeraInteractiveAction netmeraInteractiveAction) → dynamic
handleLastMessage(NetmeraCategory category) → dynamic
handlePushObject(String pushId) → dynamic
identifyUser(NetmeraUser user, {void onSuccess()?, void onFailure(dynamic error)?}) → void
Identifies the user. Only userId, email, msisdn are sent. If onSuccess or onFailure is provided, the call is callback-based; otherwise fire-and-forget.
inboxUpdateStatus(List<String> inboxList, int status) Future
isNetmeraRemoteMessage(Map data) bool
isPushEnabled() Future<bool?>
kill() → dynamic
onNetmeraFirebasePushMessageReceived(String? from, Map data) → dynamic
onNetmeraHuaweiPushMessageReceived(String? from, Map data) → dynamic
onNetmeraNewToken(String pushToken) → dynamic
onWidgetUrlTriggered(Function handler) → dynamic
requestPermissionsForLocation() → dynamic
requestPushNotificationAuthorization() Future<bool>
sendEvent(NetmeraEvent event) → void
sendGenericEvent(String code, Map<String, dynamic> attributes) → void
Sends a generic (custom) event with code and attributes to the Netmera. Use this for events that are not pre-defined in NetmeraEvent.
setAppGroupName(String appGroupName) → dynamic
setEmailPermission(bool isAllowed) Future<void>
setNetmeraMaxActiveRegions(int maxActiveRegions) → dynamic
setSmsPermission(bool isAllowed) Future<void>
setUserCategoryPreference(int categoryId, bool categoryEnabled) Future
setWhatsAppPermission(bool isAllowed) Future<void>
startDataTransfer() → dynamic
stopDataTransfer() → dynamic
turnOffSendingEventAndUserUpdate(bool turnOff) → dynamic
updateAll(int inboxStatus) Future
updateStatusByCategories(int inboxStatus, List<String> categoryList) Future
updateUserProfile(NetmeraUserProfile userProfile, {void onSuccess()?, void onFailure(dynamic error)?}) → void