NetmeraCarouselObject class
Constructors
- NetmeraCarouselObject({String? id, String? picturePath, NetmeraPushAction? action})
-
const
- NetmeraCarouselObject.fromJson(dynamic json)
-
factory
Properties
- action → NetmeraPushAction?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- picturePath → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited