NetmeraProfileAttribute<T> class
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPendingChanges → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendOperation(
Map< String, dynamic> op) → void -
getOperations(
) → List< Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
T value) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unset(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited