NetmeraProfileAttributeCollection<T> class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
hasPendingChanges bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<T> value) → void
appendOperation(Map<String, dynamic> op) → void
inherited
getOperations() List<Map<String, dynamic>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(List<T> value) → void
set(List<T> value) → void
inherited
toString() String
A string representation of this object.
inherited
unset() → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited