NetmeraPushObject class
Constructors
-
NetmeraPushObject({NetmeraPushType? pushType, String? pushId, String? pushInstanceId, int? inboxStatus, String? category, List? categories, Map? customJson, String? title, String? subtitle, String? body, String? mediaAttachmentURL, String? externalId, String? sendDate, String? expireTime, NetmeraPushAction? pushAction, String? deepLinkUrl, String? webPageUrl, List<
NetmeraInteractiveAction> interactiveActions = const [], List<NetmeraCarouselObject> carousel = const []}) -
const
- NetmeraPushObject.fromJson(Map json)
-
factory
Properties
- body → String?
-
final
-
carousel
→ List<
NetmeraCarouselObject> -
final
- categories → List?
-
final
- category → String?
-
final
- customJson → Map?
-
final
- deepLinkUrl → String?
-
final
- expireTime → String?
-
final
- externalId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inboxStatus → int?
-
final
-
interactiveActions
→ List<
NetmeraInteractiveAction> -
final
- mediaAttachmentURL → String?
-
final
- pushAction → NetmeraPushAction?
-
final
- pushId → String?
-
final
- pushInstanceId → String?
-
final
- pushType → NetmeraPushType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendDate → String?
-
final
- subtitle → String?
-
final
- title → String?
-
final
- webPageUrl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited