NetmeraPushType enum
Values
- undefined → const NetmeraPushType
-
const NetmeraPushType(0) - standard → const NetmeraPushType
-
const NetmeraPushType(1) - interactive → const NetmeraPushType
-
const NetmeraPushType(2) - popup → const NetmeraPushType
-
const NetmeraPushType(3) - silent → const NetmeraPushType
-
const NetmeraPushType(6) - ping → const NetmeraPushType
-
const NetmeraPushType(7) - configUpdate → const NetmeraPushType
-
const NetmeraPushType(8) - inAppMessage → const NetmeraPushType
-
const NetmeraPushType(10) - recall → const NetmeraPushType
-
const NetmeraPushType(11) - review → const NetmeraPushType
-
const NetmeraPushType(12) - forceUpdate → const NetmeraPushType
-
const NetmeraPushType(13) - widget → const NetmeraPushType
-
const NetmeraPushType(14)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromInt(
int? value) → NetmeraPushType?
Constants
-
values
→ const List<
NetmeraPushType> - A constant List of the values in this enum, in order of their declaration.