NetmeraUser class

User object for identify. Uses Optional so we can tell "not set" from "set to null".

Constructors

NetmeraUser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmail() String?
getIdentifyPayload() Map<String, dynamic>
Only includes keys that were explicitly set; value may be null (absent).
getMsisdn() String?
getUserId() String?
getWhatsAppNumber() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmail(String? value) → dynamic
setMsisdn(String? value) → dynamic
setUserId(String? value) → dynamic
setWhatsAppNumber(String? value) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited