NetmeraUser class

Copyright (c) 2026 Netmera Research.

Constructors

NetmeraUser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getEmail() String?
getMsisdn() String?
getUserId() String?
getWhatsAppNumber() String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmail(String value) → dynamic
setMsisdn(String value) → dynamic
setUserId(String value) → dynamic
setWhatsAppNumber(String value) → dynamic
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited